@@ -38,7 +38,8 @@ import shutil
 from collections import MutableSet
 from update_tasks import EmergeMark
 
-from calculate.lib.utils.portage import (Git, Layman, EmergeLog, GitError,
+from calculate.lib.utils.git import Git, GitError
+from calculate.lib.utils.portage import (Layman, EmergeLog,
                                          EmergeLogNamedTask, PackageList,
                                          PackageInformation,
                                          get_packages_files_directory,
