@@ -21,13 +21,15 @@ from os import path
 from calculate.lib.datavars import (Variable, VariableError,
                                     ReadonlyVariable, ReadonlyTableVariable,
                                     TableVariable, FieldValue,
+                                    HumanReadable,
                                     SimpleDataVars, DataVarsError)
 from calculate.lib.utils.files import readFile, listDirectory, process, pathJoin
 
 from calculate.lib.configparser import ConfigParser
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.lib.utils.text import simplify_profiles
-from calculate.lib.utils.portage import Git, GitError, Layman
+from calculate.lib.utils.git import Git, GitError
+from calculate.lib.utils.portage import Layman
 from ..profile import (RepositoryStorageSet, DEFAULT_BRANCH,
                        LocalStorage, ProfileRepository, CacheStorage)
 
@@ -303,10 +305,12 @@ class VariableClUpdateBinhostData(ReadonlyTableVariable):
         except urllib2.URLError as e:
             pass
         except BaseException as e:
+            if isinstance(e, KeyboardInterrupt):
+                raise
             pass
         return "", -1
 
-    def get(self, hr=False):
+    def get(self, hr=HumanReadable.No):
         binhost = self.Get('cl_update_binhost')
         recheck = self.GetBool('cl_update_binhost_recheck_set')
 
@@ -551,7 +555,7 @@ class VariableClUpdateOtherRepData(ReadonlyTableVariable):
             if rname in layman_overlays and rname not in repNames:
                 yield (rname, rpath)
 
-    def get(self, hr=False):
+    def get(self, hr=HumanReadable.No):
         return list(self.generator())
 
 class VariableClUpdateOtherRepName(FieldValue,ReadonlyVariable):
@@ -714,7 +718,7 @@ class VariableClUpdateProfileDependData(ReadonlyTableVariable):
         return False
 
 
-    def get(self, hr=False):
+    def get(self, hr=HumanReadable.No):
         dv = self.Get(self.datavars)
         # TODO:  неиспользуемая переменная возможно
         # испольуется для инициализации
@@ -914,7 +918,7 @@ class VariableClUpdateProfileUrl(Variable):
                     return ""
                 git = Git()
                 return git.get_url(profile, "origin") or ""
-        except:
+        except Exception:
             pass
         return self.default_url
 
@@ -977,7 +981,7 @@ class VariableClProfileRepository(ReadonlyVariable):
                 return ""
             ls = LocalStorage(path.dirname(profile_dn))
             return ProfileRepository(path.basename(profile_dn), ls)
-        except:
+        except Exception:
             return ""
 
 
@@ -992,7 +996,7 @@ class VariableClProfileData(ReadonlyTableVariable):
         arch = self.Get('os_arch_machine_gentoo')
         return [x for x in profiles if x.arch == arch]
 
-    def get(self, hr=False):
+    def get(self, hr=HumanReadable.No):
         rep = self.Get(self.repository)
         if not rep:
             return [[]]
